@@ -41,43 +41,81 @@ static const struct _xgi_vrate {
 	{1,  320,  200,  70,  TRUE},
 	{1,  320,  240,  60,  TRUE},
 	{1,  400,  300,  60,  TRUE},
-        {1,  512,  384,  60,  TRUE},
+    {1,  512,  384,  60,  TRUE},
 	{1,  640,  400,  72,  TRUE},
-	{1,  640,  480,  60,  TRUE}, {2,  640,  480,  72,  TRUE}, {3,  640,  480,  75,  TRUE},
-	{4,  640,  480,  85,  TRUE}, {5,  640,  480, 100,  TRUE}, {6,  640,  480, 120,  TRUE},
-	{7,  640,  480, 160, FALSE}, {8,  640,  480, 200, FALSE},
+	{1,  640,  480,  60,  TRUE}, 
+	{2,  640,  480,  72,  TRUE}, 
+	{3,  640,  480,  75,  TRUE},
+	{4,  640,  480,  85,  TRUE}, 
+	{5,  640,  480, 100,  TRUE}, 
+	{6,  640,  480, 120,  TRUE},
+	{7,  640,  480, 160, FALSE}, 
+	{8,  640,  480, 200, FALSE},
 	{1,  720,  480,  60,  TRUE},
 	{1,  720,  576,  58,  TRUE},
 	{1,  768,  576,  58,  TRUE},
-	{1,  800,  480,  60,  TRUE}, {2,  800,  480,  75,  TRUE}, {3,  800,  480,  85,  TRUE},
-	{1,  800,  600,  56,  TRUE}, {2,  800,  600,  60,  TRUE}, {3,  800,  600,  72,  TRUE},
-	{4,  800,  600,  75,  TRUE}, {5,  800,  600,  85,  TRUE}, {6,  800,  600, 105,  TRUE},
-	{7,  800,  600, 120, FALSE}, {8,  800,  600, 160, FALSE},
-	{1,  848,  480,  39,  TRUE}, {2,  848,  480,  60,  TRUE},
-	{1,  856,  480,  39,  TRUE}, {2,  856,  480,  60,  TRUE},
-	{1, 1024,  576,  60,  TRUE}, {2, 1024,  576,  75,  TRUE}, {3, 1024,  576,  85,  TRUE},
+	{1,  800,  480,  60,  TRUE}, 
+	{2,  800,  480,  75,  TRUE}, 
+	{3,  800,  480,  85,  TRUE},
+	{1,  800,  600,  56,  TRUE}, 
+	{2,  800,  600,  60,  TRUE}, 
+	{3,  800,  600,  72,  TRUE},
+	{4,  800,  600,  75,  TRUE}, 
+	{5,  800,  600,  85,  TRUE}, 
+	{6,  800,  600, 105,  TRUE},
+	{7,  800,  600, 120, FALSE}, 
+	{8,  800,  600, 160, FALSE},
+	{1,  848,  480,  39,  TRUE}, 
+	{2,  848,  480,  60,  TRUE},
+	{1,  856,  480,  39,  TRUE}, 
+	{2,  856,  480,  60,  TRUE},
+	{1, 1024,  576,  60,  TRUE}, 
+	{2, 1024,  576,  75,  TRUE}, 
+	{3, 1024,  576,  85,  TRUE},
 	{1, 1024,  600,  60,  TRUE},
-	{1, 1024,  768,  43,  TRUE}, {2, 1024,  768,  60,  TRUE}, {3, 1024,  768,  70, FALSE},
-	{4, 1024,  768,  75, FALSE}, {5, 1024,  768,  85,  TRUE}, {6, 1024,  768, 100,  TRUE},
+	{1, 1024,  768,  43,  TRUE}, 
+	{2, 1024,  768,  60,  TRUE}, 
+	{3, 1024,  768,  70, FALSE},
+	{4, 1024,  768,  75, FALSE}, 
+	{5, 1024,  768,  85,  TRUE}, 
+	{6, 1024,  768, 100,  TRUE},
 	{7, 1024,  768, 120,  TRUE},
 	{1, 1152,  768,  60,  TRUE},
-	{1, 1152,  864,  75,  TRUE}, {2, 1152,  864,  84, FALSE},
-	{1, 1280,  720,  60,  TRUE}, {2, 1280,  720,  75, FALSE}, {3, 1280,  720,  85,  TRUE},
+	{1, 1152,  864,  75,  TRUE}, 
+	{2, 1152,  864,  84, FALSE},
+	{1, 1280,  720,  60,  TRUE}, 
+	{2, 1280,  720,  75, FALSE}, 
+	{3, 1280,  720,  85,  TRUE},
 	{1, 1280,  768,  60,  TRUE},
 	{1, 1280,  800,  60,  TRUE},
-	{1, 1280,  960,  60,  TRUE}, {2, 1280,  960,  85,  TRUE},
-	{1, 1280, 1024,  43, FALSE}, {2, 1280, 1024,  60,  TRUE}, {3, 1280, 1024,  75, FALSE},
+	{1, 1280,  960,  60,  TRUE}, 
+	{2, 1280,  960,  85,  TRUE},
+	{1, 1280, 1024,  43, FALSE}, 
+	{2, 1280, 1024,  60,  TRUE}, 
+	{3, 1280, 1024,  75, FALSE},
 	{4, 1280, 1024,  85,  TRUE},
 	{1, 1360,  768,  60,  TRUE},
-	{1, 1400, 1050,  60,  TRUE}, {2, 1400, 1050,  75,  TRUE},
-	{1, 1600, 1200,  60,  TRUE}, {2, 1600, 1200,  65,  TRUE}, {3, 1600, 1200,  70,  TRUE},
-	{4, 1600, 1200,  75,  TRUE}, {5, 1600, 1200,  85,  TRUE}, {6, 1600, 1200, 100,  TRUE},
+	{1, 1400, 1050,  60,  TRUE}, 
+	{2, 1400, 1050,  75,  TRUE},
+	{1, 1600, 1200,  60,  TRUE}, 
+	{2, 1600, 1200,  65,  TRUE}, 
+	{3, 1600, 1200,  70,  TRUE},
+	{4, 1600, 1200,  75,  TRUE}, 
+	{5, 1600, 1200,  85,  TRUE}, 
+	{6, 1600, 1200, 100,  TRUE},
 	{7, 1600, 1200, 120,  TRUE},
 	{1, 1680, 1050,  60,  TRUE},
-	{1, 1920, 1440,  60,  TRUE}, {2, 1920, 1440,  65,  TRUE}, {3, 1920, 1440,  70,  TRUE},
-	{4, 1920, 1440,  75,  TRUE}, {5, 1920, 1440,  85,  TRUE}, {6, 1920, 1440, 100,  TRUE},
-	{1, 2048, 1536,  60,  TRUE}, {2, 2048, 1536,  65,  TRUE}, {3, 2048, 1536,  70,  TRUE},
-	{4, 2048, 1536,  75,  TRUE}, {5, 2048, 1536,  85,  TRUE},
+	{1, 1920, 1440,  60,  TRUE}, 
+	{2, 1920, 1440,  65,  TRUE}, 
+	{3, 1920, 1440,  70,  TRUE},
+	{4, 1920, 1440,  75,  TRUE}, 
+	{5, 1920, 1440,  85,  TRUE}, 
+	{6, 1920, 1440, 100,  TRUE},
+	{1, 2048, 1536,  60,  TRUE}, 
+	{2, 2048, 1536,  65,  TRUE}, 
+	{3, 2048, 1536,  70,  TRUE},
+	{4, 2048, 1536,  75,  TRUE}, 
+	{5, 2048, 1536,  85,  TRUE},
 	{0,    0,    0,   0, FALSE}
 };
 
